!+
! Module: rgssources_init
!
! Authors:  Ian Stewart - SSC/LUX
!          
! Description: Contains the type specification and the initialisation functions for the source data structure.
! 
! $Id: rgssources_init.f90,v 1.2 2000/08/11 13:08:45 pvideler Exp $
!- 
module rgssources_init

! You should write the module name in the 'use' statement, the package name
! (and version number) in the DEPEND file, and the * from the lib*.a name in
! <package>/src/Makefile.
  use dal

  implicit none 

  interface initSrcDataStructure
    module procedure initSrcDataStructureScalar, initSrcDataStructureVector
  end interface

  integer(int16), parameter, public ::&
    labelsize = 20,&
    myInt16null = -999,&
    epicBandNum = 2
  integer(int32), parameter, public ::&
    myInt32null = -999,&
    myOUTOFFOV = 1,&
    myCONFUSED = 2,&
    myBADBAND  = 4
  real(kind=single), parameter, public ::&
    myReal32null = -999.0
  character(len=labelsize), parameter, public ::&
    proposalLabel = 'PROPOSAL',&
    onAxisLabel = 'ONAXIS'
  type, public :: sourceType
    integer(kind=int16) ::&
      index
    integer(int32) ::&
      flag,&
      epicFileAttrNum ! has to be 32 rather than 16 so can set an integer
      ! null using the dal call setNullValue.
    character(len=labelsize) ::&
      label
    real(kind=single) ::&
      raDeg,&
      decDeg,&
      rate,&
      deltaDispArcmin,&
      deltaXdspArcmin,&
      fovRdeg,&
      fovPhiDeg,&
      confusion
    logical(kind=bool) ::&
      process,&
      bkgExclude,&
      fixedOnSky
  endType sourceType

  private
 
  public initSrcDataStructure!!!!, sourceType
!  public labelsize, myInt16null, epicBandNum, myInt32null, myReal32null
!  public myOUTOFFOV, myCONFUSED, myBADBAND

contains 

  !---------------------------------------------------------------------
  subroutine initSrcDataStructureScalar(srcData)
  !---------------------------------------------------------------------

    implicit none 

    type(sourceType), intent(out) ::&
      srcData

    type(sourceType) ::&
      srcDataVector(1)

    !-------------------------------------------------------------------
    ! Start:

    call initSrcDataStructureVector(srcDataVector)
    srcData = srcDataVector(1)

  end subroutine initSrcDataStructureScalar

  !---------------------------------------------------------------------
  subroutine initSrcDataStructureVector(srcData)
  !---------------------------------------------------------------------

    implicit none 

    type(sourceType), dimension(:), intent(out) ::&
      srcData

    !-------------------------------------------------------------------
    ! Start:

    srcData%index           = myInt16null
    srcData%label           = ''
    srcData%raDeg           = myReal32null
    srcData%decDeg          = myReal32null
    srcData%rate            = 0.0
    srcData%deltaDispArcmin = myReal32null
    srcData%deltaXdspArcmin = myReal32null
    srcData%fovPhiDeg       = myReal32null
    srcData%fovRdeg         = myReal32null
    srcData%confusion       = myReal32null
    srcData%process         = .false.
    srcData%bkgExclude      = .false.
    srcData%fixedOnSky      = .true.
    srcData%epicFileAttrNum = myInt32null
    srcData%flag            = 0

  end subroutine initSrcDataStructureVector
end module rgssources_init






